@@ -1,15 +1,19 @@
 .mgsub <- function (pattern, replacement, text.var, fixed = TRUE,
-	order.pattern = fixed, perl = TRUE, ...) {
+	order.pattern = fixed, perl = !fixed, ...) {
 
     if (fixed && order.pattern) {
         ord <- rev(order(nchar(pattern)))
         pattern <- pattern[ord]
         if (length(replacement) != 1) replacement <- replacement[ord]
     }
-    if (length(replacement) == 1) replacement <- rep(replacement, length(pattern))
+    
+    if (length(replacement) == 1) {
+        replacement <- rep(replacement, length(pattern))
+    }
 
     for (i in seq_along(pattern)){
-        text.var <- gsub(pattern[i], replacement[i], text.var, fixed = fixed, perl = perl, ...)
+        text.var <- gsub(pattern[i], replacement[i], text.var, fixed = fixed, 
+            perl = perl, ...)
     }
 
     text.var
@@ -33,7 +37,7 @@ add_row_id <- function(x){
 }
 
 title_tag_table <- function (mat) {
-    unlist(lapply(1:nrow(mat), function(i) {
+    unlist(lapply(seq_len(nrow(mat)), function(i) {
         x <- unlist(mat[i, , drop = FALSE])
         names(x[x > 0][1])
     }))
@@ -71,9 +75,19 @@ is.Integer <- function(x, tol = .Machine$double.eps^0.5) abs(x - round(x)) < tol
 
 pad <- function (x, padding = max(nchar(as.character(x))), sort = TRUE,
     type = "detect") {
+    
     poss <- c("detect", "numeric", "character", "d", "s")
-    if (!type %in% poss)
-        stop("type must be: \"detect\", \"numeric\"\\\"d\" or \"character\"\\\"s\"")
+    
+    if (!type %in% poss){
+        stop(
+            paste(
+                "type must be: \"detect\",", 
+                "\"numeric\"\\\"d\" or \"character\"\\\"s\""
+            ), 
+            call. = FALSE
+        )
+    }
+    
     Rel <- c(NA, "d", "s", "d", "s")
     type <- Rel[poss %in% type]
     if (is.na(type)) {
@@ -93,7 +107,7 @@ sprintf_ish <- function(x, padding, type){
         sprintf(paste0("%0", padding, type), x)
     } else {
         type <- ifelse(type == "s", " ", "0")
-        pads <- sapply(padding - nchar(x), function(i)  {
+        pads <- sapply2(padding - nchar(x), function(i)  {
             if (i == 0) return("")
             paste(rep(type, i), collapse = "")
         })
@@ -102,18 +116,71 @@ sprintf_ish <- function(x, padding, type){
     }
 }
 
-# ## check if dplyr is loaded (used in tibble_output function)
-# is_dplyr_loaded <- function() 'dplyr' %in% names(utils::sessionInfo()[["otherPkgs"]])
-#
-# ## convert a data.table to tibble
-# set_tibble <- function(x, ...){
-#     stopifnot(is.data.frame(x))
-#     class(x) <- c("tbl_df", "tbl", "data.frame")
-#     x
-# }
-#
-# if_tibble <- function(x, as.tibble, ...){
-#     if(!isTRUE(as.tibble)) return(x)
-#     set_tibble(x)
-# }
+
+is_numeric_doc_names <- function(x, ...){
+    UseMethod('is_numeric_doc_names')
+}
+
+
+is_numeric_doc_names.TermDocumentMatrix <- function(x, ...){
+    colnames_numeric <- suppressWarnings(as.integer(colnames(x)))
+    !anyNA(colnames_numeric) && 
+        isTRUE(all.equal(stats::sd(diff(colnames_numeric)), 0))
+}
+
+
+is_numeric_doc_names.DocumentTermMatrix <- function(x, ...){
+    rownames_numeric <- suppressWarnings(as.integer(rownames(x)))
+    !anyNA(rownames_numeric) && 
+        isTRUE(all.equal(stats::sd(diff(rownames_numeric)), 0))
+}
+
+## function to detect text columns
+detect_text_column <- function(dat, text.var){
+    
+    if (isTRUE(text.var)) {
+    
+        dat <- as.data.frame(dat, stringsAsFactors = FALSE)
+        
+        mean_lens <- unlist(lapply(dat, function(y) {
+         
+            if(!is.character(y) && !is.factor(y)) return(0)
+            mean(nchar(as.character(y)), na.rm = TRUE)
+            
+        }))
+    
+        max_cols <- which.max(mean_lens)
+        
+        text.var <- colnames(dat)[max_cols[1]]
+        
+        if (length(text.var) == 0 | sum(as.integer(mean_lens)) == 0) {
+            stop(
+                paste(
+                    "Could not detect ` text.var`.", 
+                    "Please supply `text.var` explicitly."
+                ),
+                call. = FALSE
+            )
+        }
+        
+        if (length(max_cols) > 1) {
+            warning(
+                sprintf(
+                    'More than one text column detected...using `%s`', 
+                    text.var
+                ), 
+                call. = FALSE
+            )    
+        }
+    } 
+    
+    text.var
+    
+}
+
+
+sapply2 <- function (X, FUN, ...) {
+    unlist(lapply(X, FUN, ...))
+}
+
 
